# ApiPipeline

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Output. Unique pipeline ID. Generated by API server. | [optional] 
**created_at** | **datetime** | Output. The time this pipeline is created. | [optional] 
**name** | **str** | Optional input field. Pipeline name provided by user. If not specified, file name is used as pipeline name. | [optional] 
**description** | **str** | Optional input field. Describing the purpose of the job. | [optional] 
**parameters** | [**list[ApiParameter]**](ApiParameter.md) | Output. The input parameters for this pipeline. TODO(jingzhang36): replace this parameters field with the parameters field inside PipelineVersion when all usage of the former has been changed to use the latter. | [optional] 
**url** | [**ApiUrl**](ApiUrl.md) |  | [optional] 
**error** | **str** | In case any error happens retrieving a pipeline field, only pipeline ID and the error message is returned. Client has the flexibility of choosing how to handle error. This is especially useful during listing call. | [optional] 
**default_version** | [**ApiPipelineVersion**](ApiPipelineVersion.md) |  | [optional] 
**resource_references** | [**list[ApiResourceReference]**](ApiResourceReference.md) | Input field. Specify which resource this pipeline belongs to. For Pipeline, the only valid resource reference is a single Namespace. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


